Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ClusterNetworkExpansion ¶
type ClusterNetworkExpansion interface{}
type ClusterNetworkInterface ¶
type ClusterNetworkInterface interface {
Create(*api.ClusterNetwork) (*api.ClusterNetwork, error)
Update(*api.ClusterNetwork) (*api.ClusterNetwork, error)
Delete(name string, options *pkg_api.DeleteOptions) error
DeleteCollection(options *pkg_api.DeleteOptions, listOptions pkg_api.ListOptions) error
Get(name string) (*api.ClusterNetwork, error)
List(opts pkg_api.ListOptions) (*api.ClusterNetworkList, error)
Watch(opts pkg_api.ListOptions) (watch.Interface, error)
Patch(name string, pt pkg_api.PatchType, data []byte, subresources ...string) (result *api.ClusterNetwork, err error)
ClusterNetworkExpansion
}
ClusterNetworkInterface has methods to work with ClusterNetwork resources.
type ClusterNetworksGetter ¶
type ClusterNetworksGetter interface {
ClusterNetworks(namespace string) ClusterNetworkInterface
}
ClusterNetworksGetter has a method to return a ClusterNetworkInterface. A group's client should implement this interface.
type CoreClient ¶
type CoreClient struct {
// contains filtered or unexported fields
}
CoreClient is used to interact with features provided by the k8s.io/kubernetes/pkg/apimachinery/registered.Group group.
func New ¶
func New(c restclient.Interface) *CoreClient
New creates a new CoreClient for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *restclient.Config) (*CoreClient, error)
NewForConfig creates a new CoreClient for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *restclient.Config) *CoreClient
NewForConfigOrDie creates a new CoreClient for the given config and panics if there is an error in the config.
func (*CoreClient) ClusterNetworks ¶
func (c *CoreClient) ClusterNetworks(namespace string) ClusterNetworkInterface
func (*CoreClient) RESTClient ¶
func (c *CoreClient) RESTClient() restclient.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
type CoreInterface ¶
type CoreInterface interface {
RESTClient() restclient.Interface
ClusterNetworksGetter
}